@@ -12,4 +12,4 @@ class Print(object):
 
 	def post(self, text):
 		self.json.update({'text': text})
-		return self.session.post(self.url, json=json)
+		return self.session.post(self.url, json=self.json)
